@@ -14,6 +14,8 @@ use crate::traits::ModelAble;
 use std::marker::PhantomData;
 use crate::collectors::SqlString;
 use crate::visitors;
+use crate::statements::{r#where, having};
+use crate::methods;
 // pub trait ManagerStatement<M: ModelAble> {}
 
 #[derive(Clone, Debug)]
@@ -51,28 +53,46 @@ impl<M> Table<M> where M: ModelAble {
             _marker: PhantomData
         }
     }
-    pub fn r#where(&mut self, condition: Json) -> &mut Self {
+    fn _where_statement(&mut self, condition: Json, ops: r#where::Ops) -> &mut Self {
         if let Some(select_manager) = &mut self.select_manager {
-            select_manager.r#where(condition, false);
+            select_manager.r#where(condition, ops);
         } else if let Some(update_manager) = &mut self.update_manager {
-            update_manager.r#where(condition, false);
+            update_manager.r#where(condition, ops);
         } else if let Some(delete_manager) = &mut self.delete_manager {
-            delete_manager.r#where(condition, false);
+            delete_manager.r#where(condition, ops);
         } else {
             panic!("Not support");
         }
         self
     }
+    pub fn r#where(&mut self, condition: Json) -> &mut Self {
+        self._where_statement(condition, r#where::Ops::new(r#where::JoinType::And, false, false))
+    }
     pub fn where_not(&mut self, condition: Json) -> &mut Self {
-        if let Some(select_manager) = &mut self.select_manager {
-            select_manager.r#where(condition, true);
-        } else if let Some(update_manager) = &mut self.update_manager {
-            update_manager.r#where(condition, true);
-        } else if let Some(delete_manager) = &mut self.delete_manager {
-            delete_manager.r#where(condition, true);
-        } else {
-            panic!("Not support");
-        }
+        self._where_statement(condition, r#where::Ops::new(r#where::JoinType::And, true, false))
+    }
+    pub fn where_between(&mut self, condition: Json) -> &mut Self {
+        self._where_statement(condition, r#where::Ops::new(r#where::JoinType::And, false, true))
+    }
+    pub fn where_not_between(&mut self, condition: Json) -> &mut Self {
+        self._where_statement(condition, r#where::Ops::new(r#where::JoinType::And, true, true))
+    }
+    pub fn where_or(&mut self, condition: Json) -> &mut Self {
+        self._where_statement(condition, r#where::Ops::new(r#where::JoinType::Or, false, false))
+    }
+    pub fn where_or_not(&mut self, condition: Json) -> &mut Self {
+        self._where_statement(condition, r#where::Ops::new(r#where::JoinType::Or, true, false))
+    }
+    pub fn where_or_between(&mut self, condition: Json) -> &mut Self {
+        self._where_statement(condition, r#where::Ops::new(r#where::JoinType::Or, false, true))
+    }
+    pub fn where_or_not_between(&mut self, condition: Json) -> &mut Self {
+        self._where_statement(condition, r#where::Ops::new(r#where::JoinType::Or, true, true))
+    }
+    pub fn where_range<T: ToString>(&mut self, column_name: &str, range: impl std::ops::RangeBounds<T>) -> &mut Self {
+        let table_column_name = methods::table_column_name::<M>(column_name);
+        let raw_sql = r#where::help_range_to_sql(&table_column_name, range).expect("Error: Not Support");
+        self._where_statement(json!(raw_sql), r#where::Ops::new(r#where::JoinType::And, true, true));
         self
     }
     pub fn with_select_manager(&mut self) -> &mut Self {
@@ -161,20 +181,42 @@ impl<M> Table<M> where M: ModelAble {
         }
         self
     }
-    pub fn having(&mut self, condition: Json) -> &mut Self {
+    pub fn _having_statement(&mut self, condition: Json, ops: having::Ops) -> &mut Self {
         if let Some(select_manager) = &mut self.select_manager {
-            select_manager.having(condition, false);
+            select_manager.having(condition, ops);
         } else {
             panic!("Not support");
         }
         self
     }
+    pub fn having(&mut self, condition: Json) -> &mut Self {
+        self._having_statement(condition, having::Ops::new(r#where::JoinType::And, false, false))
+    }
     pub fn having_not(&mut self, condition: Json) -> &mut Self {
-        if let Some(select_manager) = &mut self.select_manager {
-            select_manager.having(condition, true);
-        } else {
-            panic!("Not support");
-        }
+        self._having_statement(condition, having::Ops::new(r#where::JoinType::And, true, false))
+    }
+    pub fn having_between(&mut self, condition: Json) -> &mut Self {
+        self._having_statement(condition, having::Ops::new(r#where::JoinType::And, false, true))
+    }
+    pub fn having_not_between(&mut self, condition: Json) -> &mut Self {
+        self._having_statement(condition, having::Ops::new(r#where::JoinType::And, true, true))
+    }
+    pub fn having_or(&mut self, condition: Json) -> &mut Self {
+        self._having_statement(condition, having::Ops::new(r#where::JoinType::Or, false, false))
+    }
+    pub fn having_or_not(&mut self, condition: Json) -> &mut Self {
+        self._having_statement(condition, having::Ops::new(r#where::JoinType::Or, true, false))
+    }
+    pub fn having_or_between(&mut self, condition: Json) -> &mut Self {
+        self._having_statement(condition, having::Ops::new(r#where::JoinType::Or, false, false))
+    }
+    pub fn having_or_not_between(&mut self, condition: Json) -> &mut Self {
+        self._having_statement(condition, having::Ops::new(r#where::JoinType::Or, true, true))
+    }
+    pub fn having_range<T: ToString>(&mut self, column_name: &str, range: impl std::ops::RangeBounds<T>) -> &mut Self {
+        let table_column_name = methods::table_column_name::<M>(column_name);
+        let raw_sql = having::help_range_to_sql(&table_column_name, range).expect("Error: Not Support");
+        self._having_statement(json!(raw_sql), having::Ops::new(r#where::JoinType::And, true, true));
         self
     }
     pub fn order(&mut self, condition: Json) -> &mut Self {
