@@ -44,20 +44,34 @@ mod query {
         let sql = User::query()
             .r#where(json!({"name": "Tom"}))
             .r#where(json!(["active = ?", true]))
+            .r#where_not(json!({"status": [1, 2, 3]}))
+            .where_between(json!({"created_at": ["2021-12-01 00:00:00", "2021-12-31 23:59:59"]}))
+            .where_or(json!({"login": false, "phone": null}))
             .to_sql();
-        assert_eq!(sql, "SELECT `users`.* FROM `users` WHERE `users`.`name` = 'Tom' AND (active = 1)");
+        assert_eq!(sql, "SELECT `users`.* FROM `users` WHERE `users`.`name` = 'Tom' AND active = 1 AND `users`.`status` NOT IN (1, 2, 3) AND `users`.`created_at` BETWEEN '2021-12-01 00:00:00' AND '2021-12-31 23:59:59' AND (`users`.`login` = 0 OR `users`.`phone` IS NULL)");
 
         let sql = User::query()
             .r#where_not(json!({"name": "Tom", "status": [1, 2, 3]}))
             .r#where(json!(["active = ?", true]))
             .to_sql();
-        assert_eq!(sql, "SELECT `users`.* FROM `users` WHERE `users`.`name` != 'Tom' AND `users`.`status` NOT IN (1, 2, 3) AND (active = 1)");
+        assert_eq!(sql, "SELECT `users`.* FROM `users` WHERE `users`.`name` != 'Tom' AND `users`.`status` NOT IN (1, 2, 3) AND active = 1");
 
         let sql = User::query()
             .joins(json!("left join orders on users.id = orders.user_id"))
             .r#where(json!({"name": "Tom"}))
             .to_sql();
         assert_eq!(sql, "SELECT `users`.* FROM `users` left join orders on users.id = orders.user_id WHERE `users`.`name` = 'Tom'");
+
+        // range
+        let sql = User::query().where_range("age", 18..25).to_sql();
+        assert_eq!(sql, "SELECT `users`.* FROM `users` WHERE `users`.`age` >= 18 AND `users`.`age` < 25");
+        let sql = User::query().where_range("age", 18..).to_sql();
+        assert_eq!(sql, "SELECT `users`.* FROM `users` WHERE `users`.`age` >= 18");
+        let sql = User::query().where_range("age", ..=25).to_sql();
+        assert_eq!(sql, "SELECT `users`.* FROM `users` WHERE `users`.`age` <= 25");
+        // range_between
+        let sql = User::query().where_range("age", 18..=25).to_sql();
+        assert_eq!(sql, "SELECT `users`.* FROM `users` WHERE `users`.`age` BETWEEN 18 AND 25");
     }
     #[test]
     fn test_lock() {
@@ -71,8 +85,10 @@ mod query {
 
         let sql = User::query().group(json!("age"))
             .having_not(json!({"x": 1}))
-            .having(json!(["y > ?", 2])).to_sql();
-        assert_eq!(sql, "SELECT `users`.* FROM `users` GROUP BY age HAVING `users`.`x` != 1 AND (y > 2)");
+            .having(json!(["y > ?", 2]))
+            .having_range("z", 18..)
+            .to_sql();
+        assert_eq!(sql, "SELECT `users`.* FROM `users` GROUP BY age HAVING `users`.`x` != 1 AND y > 2 AND `users`.`z` >= 18");
     }
     #[test]
     fn test_order() {
